/*!
  \file  /usr/include/ebs.h
  \date 19.08.2002
  \version 0.1.1
  \author robert.sedevcic@ijs.si
  \brief This is EBS-Experimental Boundary Scan project library header file.

  See EBS project home page at http://ebsp.sourceforge.net

  Copyright (C) 2002 by CSD at http://www-csd.ijs.si
*/

/*
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

*/

#ifndef _EBS_H_
#define _EBS_H_


#ifndef DEBUG_LIB
  #define DEBUG_LIB  1
#endif


/*=============================================================================
 * function declarations which are defined in the libebs library
 *===========================================================================*/
void err_check(int ret, int line);
int hextouc(unsigned char* cptr, int mode);
unsigned char *binary_to_hex(int bytes_no, unsigned char *cptr);


/*=============================================================================
 * some predefined values used in the applications
 *===========================================================================*/
#ifndef MINOR
  #define MINOR 0
#endif

#ifndef MAJOR
  #define MAJOR 1
#endif

#ifndef ACT8990_REGS_NO
  #define ACT8990_REGS_NO 24
#endif


/*=============================================================================
 * some Minor Command predefined register values
 *===========================================================================*/
#ifndef RESET_ALL
  #define RESET_ALL 0x7001   /* reset the whole controller */
#endif

#ifndef RESET_IRQF
  #define RESET_IRQF 0x7002  /* reset the interrupt request flags */
#endif

#ifndef RESET_DATA
  #define RESET_DATA 0x7004  /* reset the data registers */
#endif

#ifndef RESET_REQF
  #define RESET_REQF 0x7008  /* reset the request flags */
#endif

#ifndef CAPTURE_STATUS
  #define CAPTURE_STATUS 0x6040  /* capture Status0,1,2 registers */
#endif

#ifndef CAPTURE_COUNTER
  #define CAPTURE_COUNTER 0x6004  /* capture Counter1 register */
#endif

#ifndef UPDATE_COUNTER
  #define UPDATE_COUNTER 0x6001   /* update Counter1 register */
#endif

#ifndef SET_CONTROL_REGS
  #define SET_CONTROL_REGS 0x8000 /* set Control registers */
#endif


/*=============================================================================
 * some Major Command predefined register values
 *===========================================================================*/
#ifndef MOVE_STATE
  #define MOVE_STATE 0x1000
#endif

#ifndef TEST_LOGIC_RESET
  #define TEST_LOGIC_RESET 0x1001
#endif

#ifndef RUN_TEST_IDLE
  #define RUN_TEST_IDLE 0x1002
#endif

#ifndef SHIFT_DR
  #define SHIFT_DR 0x1004
#endif

#ifndef SHIFT_IR
  #define SHIFT_IR 0x1005
#endif

#ifndef PAUSE_DR
  #define PAUSE_DR 0x1006
#endif

#ifndef PAUSE_IR
  #define PAUSE_IR 0x1007
#endif

#ifndef SCAN_DATA
  #define SCAN_DATA 0x3000
#endif

#ifndef SCAN_INSTR
  #define SCAN_INSTR 0x3008
#endif

#ifndef START_EXECUTE
  #define START_EXECUTE 0x20CF
#endif

/*===========================================================================
 *     Control Register offsets
 *      Reg. name  Offset Application                        Access
 *===========================================================================*/
#define CONTROL0   0      /* Interrupt enable control        (R/W)*/
#define CONTROL1   1      /* Host and test control           (R/W)*/
#define CONTROL2   2      /* TMS0-TMS5 connections           (R/W)*/
#define CONTROL3   3      /* TMS/EVENT, TDO, TMS/TCK control (R/W)*/
#define CONTROL4   4      /* Delay, data format of TDI, TDO  (R/W)*/
#define CONTROL5   5      /* Event pins data out., direction (R/W)*/
#define CONTROL6   6      /* Event choice of Event0/1 inputs (R/W)*/
#define CONTROL7   7      /* Event choice of Event2/3 inputs (R/W)*/
#define CONTROL8   8      /* Counter1 control                (R/W)*/
#define CONTROL9   9      /* Counter2 control                (R/W)*/   

/*===========================================================================
 *     Command Register offsets
 *      Reg. name     Offset Application                        Access
 *===========================================================================*/
#define MINOR_COMMAND 10     /* Interrupt, read control, ...    (R/W)*/
#define MAJOR_COMMAND 11     /* State, Execute, Scan control    (R/W)*/

/*===========================================================================
 *     Counters control Register offsets
 *      Reg. name        Offset  Application                      Access
 *===========================================================================*/
#define COUNTER1_UPDATE0 12      /* Counter1 lower value word     (R/W)*/
#define COUNTER1_UPDATE1 13      /* Counter1 higher value word    (R/W)*/
#define COUNTER2_UPDATE0 14      /* Counter2 lower word of Cou.20 (R/W)*/
#define COUNTER2_UPDATE1 15      /* Counter2 lower word of Cou.21 (R/W)*/
#define CAPTURE0 16              /* Counter1 lower value word     (R)  */
#define CAPTURE1 17              /* Counter1 higher value word    (R)  */ 

/*============================================================================
 *     Status Register offsets
 *      Reg. name Offset       Application                      Access
 *===========================================================================*/
#define STATUS0   18           /* Interrupt flag status         (R)  */
#define STATUS1   19           /* External signals and request  (R)  */
#define STATUS2   20           /* Board and buffer state        (R)  */  
#define STATUS3   21           /* Not used                      (R)  */

/*============================================================================
 *     Read/Write Registers
 *      Reg. name    Offset  Application                      Access
 *==========================================================================*/ 
#define READ_BUFFER  22      /* Input buffer for TDI          (R)  */
#define WRITE_BUFFER 23      /* Output buffer for TDO         (W)  */

#endif




